@@ -1,5 +1,5 @@
 package PAR::Heavy;
-$PAR::Heavy::VERSION = '0.11';
+$PAR::Heavy::VERSION = '0.12';
 
 =head1 NAME
 
@@ -71,7 +71,7 @@ sub _bootstrap {
     # FIXME: Config is always loaded by PAR.pm!
     $dlext ||= do {
         require Config;
-        (defined %Config::Config) ? $Config::Config{dlext} : '';
+        (%Config::Config) ? $Config::Config{dlext} : '';
     };
 
     my $modpname = join((($^O eq 'MacOS') ? ':' : '/'), @modparts);
@@ -85,7 +85,8 @@ sub _bootstrap {
 
     my $member;
     # First, try to find things in the peferentially loaded PARs:
-    $member = PAR::_find_par_internals([@PAR::PAR_INC], undef, $file, 1);
+    $member = PAR::_find_par_internals([@PAR::PAR_INC], undef, $file, 1)
+      if defined &PAR::_find_par_internals;
 
     # If that failed to find the dll, let DynaLoader (try or) throw an error
     unless ($member) { 
@@ -93,7 +94,8 @@ sub _bootstrap {
         return $filename if not $@ and defined $filename;
 
         # Now try the fallback pars
-        $member = PAR::_find_par_internals([@PAR::PAR_INC_LAST], undef, $file, 1);
+        $member = PAR::_find_par_internals([@PAR::PAR_INC_LAST], undef, $file, 1)
+          if defined &PAR::_find_par_internals;
 
         # If that fails, let dynaloader have another go JUST to throw an error
         # While this may seem wasteful, nothing really matters once we fail to
@@ -188,10 +190,10 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002-2009 by Audrey Tang
+Copyright 2002-2010 by Audrey Tang
 E<lt>cpan@audreyt.orgE<gt>.
 
-Copyright 2006-2009 by Steffen Mueller
+Copyright 2006-2010 by Steffen Mueller
 E<lt>smueller@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
